@@ -5,8 +5,6 @@ import sqlalchemy
 import warnings
 from sqlalchemy.engine import create_engine
 from sqlalchemy import MetaData, Table
-from converter.vertica.custom_insert import vertica_insert
-from converter.vertica.merge import vertica_merge
 
 warnings.filterwarnings("ignore")
 
@@ -92,6 +90,11 @@ class DataBaseWorker:
             )
         return True
 
+    def execute(self, query):
+        with self.engine.connect() as connection:
+            result = connection.execute(query)
+            return result
+
     @property
     def meta(self):
         if "schema" in self.cred:
@@ -148,99 +151,6 @@ class DataBaseWorker:
             )
         return True
 
-    def insert_vertica(self, table_name, data, schema=None, table_suffix=None):
-        """
-        custom insert for vertica using json
-        :param table_suffix: change table to insert
-        :param schema:  schema to uplaad
-        :param table_name:
-        :param data: data to insert
-        :return: nothing
-        """
-        if self.db != "vertica":
-            raise ModuleNotFoundError("Available only for vertica data source")
-        cursor = self.engine.raw_connection().cursor()
-        keys_data = list(data[0].keys())
-        columns = self.get_columns(table_name)
-        keys_to_remove = list(set(keys_data) - set(columns))
-        keys_data = [key for key in keys_data if key in columns]
-        for item in data:
-            for key in keys_to_remove:
-                if key in item:
-                    del item[key]
-        fields_json = [
-            key
-            for key in keys_data
-            if key in columns and columns[key] in ("long varbinary", "blob")
-        ]
-        vertica_insert(
-            cursor=cursor,
-            target=(schema or self.schema) + "." + table_name + (table_suffix or ""),
-            fields_json=fields_json,
-            fields=keys_data,
-            data=data,
-        )
-
-    def insert_merge_vertica(
-            self,
-            table_name,
-            data,
-            staging_schema=None,
-            schema=None,
-            staging_table_suffix=None,
-            key_fields=None,
-            filter_merge_fields=None,
-    ):
-        """
-        Insert and update data in target table using temporary staging table, only for vertica
-        :param filter_merge_fields:
-        :param key_fields:
-        :param table_name:
-        :param data:
-        :param staging_schema:
-        :param schema:
-        :param staging_table_suffix:
-        :return: Nothing
-        """
-        if key_fields is None:
-            key_fields = ["id"]
-        if self.db != "vertica":
-            raise ModuleNotFoundError("Available only for vertica data source")
-        schema = schema or self.schema
-        staging_table_name = "{staging_schema}.{table_name}{staging_table_suffix}".format(
-            staging_schema=staging_schema,
-            table_name=table_name,
-            staging_table_suffix=staging_table_suffix or "",
-        )
-        sql_create_staging = "create table {staging_table_name} like {schema}.{table_name}".format(
-            staging_table_name=staging_table_name, table_name=table_name, schema=schema
-        )
-        self.logger.info(sql_create_staging)
-        self.conn.execute(sql_create_staging)
-        try:
-            self.insert_vertica(
-                table_name,
-                data,
-                schema=staging_schema,
-                table_suffix=staging_table_suffix,
-            )
-            self.logger.info(
-                vertica_merge(
-                    conn=self.conn,
-                    table_name=schema + "." + table_name,
-                    staging_table_name=staging_table_name,
-                    fields=self.get_columns(table_name),
-                    key_fields=key_fields,
-                    filter_merge_fields=filter_merge_fields,
-                )
-            )
-        finally:
-            sql_drop = "drop table {staging_table_name} cascade".format(
-                staging_table_name=staging_table_name
-            )
-            self.logger.info(sql_drop)
-            self.conn.execute(sql_drop)
-
     def get_table_schema(self, table_name):
         columns_name = [
             "column_name",
