@@ -71,10 +71,6 @@ class FieldsConverter:
                 )
             )
 
-    def __del__(self):
-        self.db_worker_from.__del__()
-        self.db_worker_to.__del__()
-
     @property
     def __str__(self):
         return "FieldsConverter_{}_{}".format(self.from_db, self.to_db)
@@ -200,7 +196,7 @@ class FieldsConverter:
             sql = "drop table {schema}.{table} cascade ".format(
                 schema=self.db_worker_to.schema, table=table
             )
-            self.db_worker_to.conn.execute(sql)
+            self.db_worker_to.execute(sql)
 
     def create_list_of_tables(self, tables, to_create=True, dir_ddl=None, suffix=None):
         result_list = []
@@ -210,7 +206,7 @@ class FieldsConverter:
                 sql = sql.replace(");", ") " + suffix + ";")
             result_list.append(sql)
             if to_create:
-                self.db_worker_to.conn.execute(sql)
+                self.db_worker_to.execute(sql)
                 self.logger.info("creating table {} is successful".format(table))
             if dir_ddl is not None:
                 save_ddl_to_file(sql=sql, table_name=table, ddl_dir=dir_ddl)
